


import happi
import numpy as np
import matplotlib.pyplot as plt

l0 = 0.75e-6            # wavelength corresponds to 2*pi
k0 = 2*np.pi/l0         # reciprocal unit distance
c = 299792458
me = 9.10938356e-31
qe = 1.60217662e-19
perm0 = 8.8541878128e-12
omega0= c*k0            # reciprocal unit time
E0 = me*c*omega0/qe     # unit electric field
xf= 3

S=happi.Open("/cephyr/users/vojho/Hebbe/c3se/test11/", 
             reference_angular_frequency_SI=omega0)
ex=S.Field(0,"Ex")
ey=S.Field(0,"Ey")
Ex = np.array(ex.getData())*E0/1.0e12
Ey = np.array(ey.getData())*E0/1.0e12
x = ex.getAxis('x')/k0*1e6
y = ex.getAxis('y')/k0*1e6
y = y - np.max(y)/2.0
z = ex.getAxis('z')/k0*1e6
z = z - np.max(z)/2.0
center = int(np.ceil(np.shape(Ex)[3]/2.0))

#
xl1 = [0, 9]
yl1 = [0,0]
xl2 = [xf,xf]
yl2 = [-4,4]
xl = (0,9)
yl = (-4, 4)

i = 4 
maxI = 0.5*perm0*c*np.max(np.power(Ey[i],2)+np.power(Ex[i],2))*1.0e20
mes =  "Maximum intensity is %g W/cm2" % maxI
print(mes)
t = ex.getTimes()[i]/omega0*1.0e15
plt.figure(1)
plt.clf()
plt.xlim(xl)
plt.ylim(yl)
plt.imshow(np.transpose(Ex[i,:,:,center]),extent = [np.min(x), np.max(x), np.min(y), np.max(y)], cmap= "RdBu")
plt.plot(xl1,yl1, 'k--', linewidth=0.5)
plt.plot(xl2,yl2, 'k--', linewidth=0.5)
plt.xlabel(r'$x$ [$\mu$m]')
plt.ylabel(r'$y$ [$\mu$m]')
tit = r'$t$ = %0.3f [fs]' % t
plt.title(tit)
cb = plt.colorbar()
cb.ax.set_title(r'$E_x$ [TV/m]', rotation=0)
#plt.savefig('Ex.eps', format='eps', dpi=300)

plt.figure(2)
plt.clf()
plt.xlim(xl)
plt.ylim(yl)
plt.imshow(np.transpose(Ey[i,:,:,center]),
           extent = [np.min(x), np.max(x), np.min(y), np.max(y)],
           aspect='auto',
           cmap= "RdBu")
plt.plot(xl1,yl1, 'k--', linewidth=0.5)
plt.plot(xl2,yl2, 'k--', linewidth=0.5)
plt.xlabel(r'$x$ [$\mu$m]')
plt.ylabel(r'$y$ [$\mu$m]')
tit = r'$t$ = %0.3f [fs]' % t
plt.title(tit)
cb = plt.colorbar()
cb.ax.set_title(r'$E_y$ [TV/m]', rotation=0)
#plt.savefig('Ey.eps', format='eps', dpi=300)
#
